@@ -6,6 +6,7 @@ pub struct Serializer<W: Write> {
     pub(crate) w: W,
 }
 impl<W: Write> Serializer<W> {
+    #[cfg_attr(feature = "inline", inline)]
     pub fn new(w: W, revision: u32) -> BinverseResult<Self> {
         let mut s = Self { w };
         revision.serialize(&mut s)?;
@@ -13,14 +14,17 @@ impl<W: Write> Serializer<W> {
     }
 
     /// Create a new Serializer, but without writing the revision into the stream
+    #[cfg_attr(feature = "inline", inline)]
     pub fn new_no_revision(w: W) -> Self {
         Self { w }
     }
 
+    #[cfg_attr(feature = "inline", inline)]
     pub fn write(&mut self, buf: &[u8]) -> BinverseResult<()> {
         self.w.write_all(buf)?;
         Ok(())
     }
+    #[cfg_attr(feature = "inline", inline)]
     pub fn write_size(&mut self, sb: SizeBytes, size: usize) -> BinverseResult<()> {
         use SizeBytes::*;
         let max_size = match sb {
@@ -40,12 +44,13 @@ impl<W: Write> Serializer<W> {
             SizeBytes::Var   => varint::write(size as u64, &mut self.w)
         }
     }
+    #[cfg_attr(feature = "inline", inline)]
     pub fn serialize_sized<T: SizedSerialize<W>>(&mut self, sb: SizeBytes, t: &T) -> BinverseResult<()> {
         let size = t.size();
         self.write_size(sb, size)?;
         t.serialize_sized(self, size)
     }
-    //pub fn revision(&self) -> u32 { self.revision }
+    #[cfg_attr(feature = "inline", inline)]
     pub fn finish(self) -> W { self.w }
 }
 
@@ -55,6 +60,7 @@ pub struct Deserializer<R: Read> {
 }
 
 impl<R: Read> Deserializer<R> {
+    #[cfg_attr(feature = "inline", inline)]
     pub fn new(r: R) -> BinverseResult<Self> {
         let mut d = Self {
             r,
@@ -67,14 +73,17 @@ impl<R: Read> Deserializer<R> {
     /// Create a new Deserializer, but without reading the revision from the stream.
     /// Instead, the revision has to be passed. Providing data created in a different
     /// revision than specified can lead to invalid data or errors
+    #[cfg_attr(feature = "inline", inline)]
     pub fn new_no_revision(r: R, revision: u32) -> Self {
         Self { r, revision }
     }
     
+    #[cfg_attr(feature = "inline", inline)]
     pub fn read(&mut self, buf: &mut [u8]) -> BinverseResult<()> {
         self.r.read_exact(buf)?;
         Ok(())
     }
+    #[cfg_attr(feature = "inline", inline)]
     pub fn read_size(&mut self, sb: SizeBytes) -> BinverseResult<usize>  {
         Ok(match sb {
             SizeBytes::One   => self.deserialize::< u8>()? as usize,
@@ -84,11 +93,15 @@ impl<R: Read> Deserializer<R> {
             SizeBytes::Var   => varint::read(&mut self.r)? as usize
         })
     }
+    #[cfg_attr(feature = "inline", inline)]
     pub fn deserialize<T: Deserialize<R>>(&mut self) -> BinverseResult<T> { T::deserialize(self) }
+    #[cfg_attr(feature = "inline", inline)]
     pub fn deserialize_sized<T: SizedDeserialize<R>>(&mut self, sb: SizeBytes) -> BinverseResult<T> {
         let size = self.read_size(sb)?;
         T::deserialize_sized(self, size)
     }
+    #[cfg_attr(feature = "inline", inline)]
     pub fn revision(&self) -> u32 { self.revision }
+    #[cfg_attr(feature = "inline", inline)]
     pub fn finish(self) -> R { self.r }
 }
\ No newline at end of file
